makeTrialLabels: makeTrialLabels function

View source: R/makeTrialLabels.R

makeTrialLabelsR Documentation

makeTrialLabels function

Description

function to (do something)

Usage

makeTrialLabels(
  labPos,
  shiftLab,
  labNames,
  cols,
  a = 0,
  labh = 8,
  labw = 60,
  rotateLabs = 0,
  labPlots = TRUE,
  ...
)

Arguments

labPos

matrix with 2 columns indicating x and y positions of labels, or a list of vectors of length 2, with x and y coordinates per label, or a list of fieldPlots objects.

shiftLab

list of vector of vertical adjustments for trial labels, useful when fieldplots are provided to labPos, to adjust the label position vertically

labNames

vector of label names.

cols

colors to be used for label names

a

numeric. angle at which labels should be drawn. Default is 0.

labh

numeric. label height. Default is 8

labw

numeric. label width. Default is 60

rotateLabs

numjeric. rotation for labels. Default is 0

labPlots

logical. Should plots be labeled? Useful for map development when set to FALSE to not print labels. Default is TRUE

...

additional arguments passed to text()

Details

[fill in details here]

Value

[value]

Examples

# none

nsantantonio/fieldMapR documentation built on Feb. 4, 2025, 3:07 a.m.