randomizeTrial: randomizeTrial function

View source: R/randomizeTrial.R

randomizeTrialR Documentation

randomizeTrial function

Description

function to randomize trials

Usage

randomizeTrial(
  ent,
  test,
  year,
  loc,
  reps,
  grams,
  randomize = "RCBD",
  entryGrams = NULL,
  entryTKW = NULL,
  nSeeds = NULL,
  otherCols = NULL,
  TKWdigits = 0,
  sendToBlock = NULL
)

Arguments

ent

data.frame with entry information, including Line, Pedigree, Entry, source columns

test

character. Test name, usually the same every year (e.g. GulfAtlantic, UniformEastern), cannot contain spaces!

year

integer. year of trial evaluation

loc

character. Location name or abbreviation. Pipeline is specifically set up to deal with 5 letter capital letter abbreviations with the first three indicating the city and the last two indicating the state. Other patterns may result in unexpected behavior.

reps

integer. vector of integers containing the number of replicates for all line s (length 1) or every line (length n).

grams

numeric. number of grams per plot.

randomize

character. Randomization to be performed. Valid randomizations include "RCBD" and "augmented". Supplying "no" to this argument will result in no randomization being performed. Default is 'RCBD'

entryGrams

numeric. Vector of length n for grams for each entry. Default is NULL

entryTKW

numeric. Thousand kernel weights per entry, length n.

nSeeds

numeric. Number of seeds per plot

otherCols

characteer. other column names in ent to be kept in randomization output. This is typically unnecessary. Default is NULL

TKWdigits

integer. rounding digits for output of grams per plot calculated from entryTKW & nSeeds

sendToBlock

list. named list indicating which lines should be put in which blocks. Each location needs its own list element, and within each location, a list of lines for each block may be given. (names of list element) under an sugmented design. This is useful when specific lines need to be in one block due to harvesting / seed saving. Can be any length 1 to n lines. Only applicable to augmented designs. Default is NULL

Details

[fill in details here]

Value

[value] object of class fieldTrial

Examples

# none

nsantantonio/fieldMapR documentation built on Feb. 4, 2025, 3:07 a.m.