reRandomizeTrial: reRandomizeTrial function

View source: R/reRandomizeTrial.R

reRandomizeTrialR Documentation

reRandomizeTrial function

Description

function to re-randomize trials. Useful if the grower wants to plant multiple locations were blocks can be harvested for seed in some or all locations.

Usage

reRandomizeTrial(
  ent,
  rando,
  test = NULL,
  year = NULL,
  loc = NULL,
  grams = NULL
)

Arguments

ent

[value]

rando

previous randomization output from randomizeTrial()

test

[value]

year

[value]

loc

[value]

grams

[value]

Details

[fill in details here]

Value

[value] object of class fieldTrial

Examples

# none

nsantantonio/fieldMapR documentation built on Feb. 4, 2025, 3:07 a.m.