| drawPlots | R Documentation |
function to draw plots on an R graphics device.
drawPlots(
plots,
angle = 0,
labAngle = angle + 90,
plotNos = TRUE,
add = TRUE,
ptrim = 1,
rtrim = 2,
color = NA,
showBorderNum = FALSE,
...
)
plots |
object of class 'fieldPlots' |
angle |
numeric. Angle of which to draw plots |
labAngle |
numeric. Angle at which to draw plot labels |
plotNos |
logical. Should plot numbers be displayed? Default is TRUE |
add |
logical. should plots be drawn on an existing R device? Default is TRUE |
ptrim |
numeric. Distance to remove between passes when drawing plots. Example, passes may be 5 feet wide, but plots are only 4 feet wide, then ptrim should be 5-4=1. Default is 1 |
rtrim |
numeric. Distance to remove between passes when drawing plots. Example, passes may be 16 feet apart, but plots are then trimmed to 14 feet long, then rtrim should be 16-14=2.Default is 2 |
color |
character. color to be used for plots |
showBorderNum |
logical. Should border numbers be shown? |
... |
arguments passed to text() |
drawPlots draws a graphical representation of field plots to an R device, such as a pdf.
nothing
# none
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.