View source: R/reRandomizeTrial.R
| reRandomizeTrial | R Documentation |
function to re-randomize trials. Useful if the grower wants to plant multiple locations were blocks can be harvested for seed in some or all locations.
reRandomizeTrial(
ent,
rando,
test = NULL,
year = NULL,
loc = NULL,
grams = NULL
)
ent |
[value] |
rando |
previous randomization output from randomizeTrial() |
test |
[value] |
year |
[value] |
loc |
[value] |
grams |
[value] |
[fill in details here]
[value] object of class fieldTrial
# none
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.